Icon class

Icon

Properties

hasAlpha bool
Check image has an alpha channel
no setter
hashCode int
The hash code for this object.
no setterinherited
image ↔ Image
Image
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertToGrayscale() → void
convertToWhite() → void
copyResized(int iconSize) Icon
Create a resized copy of this Icon
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAlpha() → void
Remove alpha channel from the image
saveResizedPng(int iconSize, String filePath) → void
Save the resized image to a file
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadFile(String filePath) Icon?
Load an image from file. If filePath was previously resolved from an SVG source via resolveSvgImagePath, the rasterized PNG bytes are taken directly from memory instead of reading a file from disk.
saveIco(List<Icon> icons, String filePath) → void
Save the resized image to a Windows ico file