Icon class
Icon
Properties
Methods
-
convertToGrayscale(
) → void -
convertToWhite(
) → void -
copyResized(
int iconSize) → Icon - Create a resized copy of this Icon
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAlpha(
) → void - Remove alpha channel from the image
-
saveResizedPng(
int iconSize, String filePath) → void - Save the resized image to a file
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadFile(
String filePath) → Icon? -
Load an image from file. If
filePathwas previously resolved from an SVG source viaresolveSvgImagePath, the rasterized PNG bytes are taken directly from memory instead of reading a file from disk. -
saveIco(
List< Icon> icons, String filePath) → void - Save the resized image to a Windows ico file